@@ -19,6 +19,9 @@ def parse_extra(extra):
         "--doi",
         "--allcontrib-type",
         "--allcontrib-file",
+        "--codemeta-file",
+        "--mailmap-file",
+        "--skip-users",
     ]
     known_bool = []
 
