@@ -61,12 +61,27 @@ class AllContribParser(ParserBase):
 
     def __init__(self, filename=None, repo=None, params=None):
         filename = filename or ".all-contributorsrc"
+        self.extras = []
         super().__init__(filename, repo, params)
 
     def load_data(self):
         return self._load_data("--allcontrib-file")
 
-    def init(self, force=False):
+    @property
+    def login_lookup(self):
+        self.load_data()
+        return {
+            x["login"]: x for x in self.data.get("contributors", []) if "login" in x
+        }
+
+    @property
+    def name_lookup(self):
+        """Return loaded metadata as an name lookup.
+        """
+        self.load_data()
+        return {x["name"]: x for x in self.data.get("contributors", []) if "name" in x}
+
+    def init(self, force=False, from_resources=None, save=True):
         """Given an allcontributors file (we default to the one expected) and
            a preference to force, write the empty file to the repository.
            If the file exists and force is false, exit on error. If the user
@@ -98,15 +113,18 @@ class AllContribParser(ParserBase):
             "contributors": [],
             "contributorsPerLine": 7,
         }
-        write_json(metadata, filename)
+        if save:
+            write_json(metadata, filename)
         return metadata
 
-    def update(self, thresh=1):
+    def update(self, thresh=1, from_resources=None, save=True):
         """Given an existing contributors file, use the GitHub API to retrieve
            all contributors, and then use subprocess to update the file
         """
         self.thresh = thresh
         self.load_data()
+        from_resources = from_resources or {}
+
         bot.info(f"Updating {self.filename}")
 
         # Get optional (or default) contributor type
@@ -116,11 +134,6 @@ class AllContribParser(ParserBase):
                 f"Invalid contribution type {ctype}. See https://allcontributors.org/docs/en/emoji-key for types."
             )
 
-        # Load the previous contributors, create a lookup
-        self.lookup = {
-            x["login"]: x for x in self.data.get("contributors", []) if "login" in x
-        }
-
         # Sanity check that we have the correct repository
         repo = "%s/%s" % (self.data["projectOwner"], self.data["projectName"])
 
@@ -133,16 +146,51 @@ class AllContribParser(ParserBase):
         # Update the cache from GitHub, and .tributors lookup
         self.update_cache()
 
-        for login, _ in self.repo.contributors.items():
+        # Parse over logins, start with existing values
+        self.lookup = {
+            x["login"]: x for x in self.data.get("contributors", []) if "login" in x
+        }
+        self.extras = [x for x in self.data.get("contributors", []) if "login" not in x]
+
+        # This client only supports update from names and logins
+        self.update_from_logins(from_resources.get("login", []), ctype)
+        self.update_from_names(from_resources.get("names", []), ctype)
+        self.update_from_orcids(from_resources.get("orcid", []))
+        self.update_from_emails(from_resources.get("email", []))
+
+        # Update the contributors
+        self.data["contributors"] = list(self.lookup.values()) + self.extras
+
+        if save:
+            write_json(self.data, self.filename)
+        return self.data
+
+    def update_from_names(self, names, ctype):
+        """Given a list of names, update the loaded logins
+        """
+        for name in names:
+            if name not in self.name_lookup:
+                bot.info(f"⭐️ Found new contributor {name} in {self.filename}")
+                entry = {
+                    "name": name,
+                    "contributions": [ctype],
+                }
+                self.extras.append(entry)
+
+    def update_from_logins(self, logins, ctype):
+        """Given a list of logins, update the loaded logins
+        """
+        for login in logins:
 
             # Check against contribution threshold, and not bot
             if not self.include_contributor(login):
                 continue
 
             cache = self.cache.get(login) or {}
-            if login in self.lookup:
-                entry = self.lookup[login]
+            if login in self.login_lookup:
+                entry = self.login_lookup[login]
             else:
+                bot.info(f"⭐️ Found new contributor {login} in {self.filename}")
                 entry = {
                     "login": login,
                     "name": cache.get("name") or login,
@@ -163,11 +211,6 @@ class AllContribParser(ParserBase):
                 entry["contributions"].append(ctype)
             self.lookup[login] = entry
 
-        # Update the contributors
-        self.data["contributors"] = list(self.lookup.values())
-        write_json(self.data, self.filename)
-        return self.data
-
     def update_lookup(self):
         """Each client optionally has it's own function to update the cache.
            In the case of allcontributors, we run this function on update after
@@ -177,11 +220,8 @@ class AllContribParser(ParserBase):
            to add items that would be found there.
         """
         self.load_data()
-        self.lookup = {
-            x["login"]: x for x in self.data.get("contributors", []) if "login" in x
-        }
         bot.info(f"Updating .tributors cache from {self.filename}")
-        for login, metadata in self.lookup.items():
+        for login, metadata in self.login_lookup.items():
             if login in self.cache:
                 entry = self.cache[login]
             else:
